@@ -50,7 +50,7 @@ def get_model_creator(**kwargs):
         inst_params.update({v: kwargs[v] for v in ('window_size', 'left_k', 'window_behavior', 'min_slices',
                                                    'adjust_line', 'start_est', 'apply_weights', 'regul_alpha',
                                                    'regul_n', 'regul_slice', 'regul_prior')})
-        m = ModelWindowRec if 'NewDist' in inst_params['dist'] else ModelWindow
+        m = ModelWindowRec if 'CDNB' in inst_params['dist'] else ModelWindow
     elif name == 'slices':
         m = ModelMixtures
     elif name == 'slice':
